pub async fn periodic_monitoring(
kernel_stats_proxy: StatsProxy,
attribution_data_service: &impl AttributionDataProvider,
stall_provider: &impl StallProvider,
metric_event_logger: &MetricEventLoggerProxy,
bucket_definitions: &[BucketDefinition],
inspect_root: Node,
) -> Result<()>Expand description
Periodically collect and report memory attribution data.
This produces a simplified schedule where, instead of having independent reports on their own cadence, we collect based on cobalt’s frequency and produce all other reports based on that one collection, saving significant CPU at the expense of flexibility.